@@ -18,7 +18,7 @@
  */
 
 /*
- * $Id: GCGBPTransport.c,v 1.7 2002/09/18 19:52:44 rousseau Exp $
+ * $Id: GCGBPTransport.c,v 1.9 2004/07/03 21:42:45 rousseau Exp $
  *
  */
 
@@ -26,8 +26,7 @@
 
 #include "Config.h"
 #include "GCdebug.h"
-#include "pcscdefines.h"
-#include "ifdhandler.h"
+#include "gempc_ifdhandler.h"
 #include "gbpserial.h"
 #include "GemCore.h"
 #include "GCTransport.h"
@@ -112,7 +111,7 @@ status_t GCSendCommand(DWORD Lun, DWORD nLengthIn,
 
 	if (GC_TR_BUF_SIZE <= nLengthIn)
 	{
-		// Buffer is too small (should not happen)
+		/* Buffer is too small (should not happen) */
 		creturn_value = STATUS_DEVICE_PROTOCOL_ERROR;
 		goto finally;
 	}
@@ -129,16 +128,16 @@ again:
 	nlength = sizeof(pctr_to_card_buffer);
 	if ((rv = ReadGBP(Lun, &nlength, pctr_to_card_buffer)) != STATUS_SUCCESS)
 	{
-		// The reader reports an error.
+		/* The reader reports an error. */
 
-		// Unknown NAD, retry the command
+		/* Unknown NAD, retry the command */
 		if (rv == STATUS_NAD_UNKNOWN)
 		{
 			DEBUG_COMM("wrong NAD, resent sequence");
 			goto again;
 		}
 
-		// resent sequence 0
+		/* resent sequence 0 */
 		if (rv == STATUS_PCB_REP_0)
 		{
 			DEBUG_COMM("resent sequence n0");
@@ -146,7 +145,7 @@ again:
 			goto again;
 		}
 
-		// resent sequence 1
+		/* resent sequence 1 */
 		if (rv == STATUS_PCB_REP_1)
 		{
 			DEBUG_COMM("resent sequence n1");
@@ -164,7 +163,7 @@ again:
 	}
 	if (nlength < 1)
 	{
-		// length byte not received
+		/* length byte not received */
 		creturn_value = STATUS_DEVICE_PROTOCOL_ERROR;
 		goto finally;
 	}
@@ -176,7 +175,7 @@ finally:
 	if (creturn_value != STATUS_SUCCESS)
 		*pnLengthOut = 0;
 
-	// Clear buffer
+	/* Clear buffer */
 	bzero(pctr_to_card_buffer, sizeof(pctr_to_card_buffer));
 
 	return creturn_value;
