@@ -1,6 +1,6 @@
 /*
  *  GemPC410Utils.h
- *  $Id: GemPC410Utils.h,v 1.2 2004/01/20 13:41:17 rousseau Exp $
+ *  $Id: GemPC410Utils.h,v 1.3 2004/07/03 21:11:42 rousseau Exp $
  *  GemPC410 dedicated functions
  *
  *  Created by giraud on Sat Oct 20 2001.
@@ -12,7 +12,7 @@
 #ifndef _GEMPC410UTILS_H_
 #define _GEMPC410UTILS_H_
 
-RESPONSECODE OpenGemPC410ByName(DWORD lun, LPSTR dev_name);
+RESPONSECODE OpenGemPC410ByName(DWORD lun, LPTSTR dev_name);
 RESPONSECODE OpenGemPC410(DWORD lun, DWORD channel);
 RESPONSECODE CloseGemPC410(DWORD lun);
 
