@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: gbpserial.c,v 1.34 2004/01/20 13:58:55 rousseau Exp $
+ * $Id: gbpserial.c,v 1.36 2004/07/03 21:11:42 rousseau Exp $
  */
 
 #include <stdlib.h>
@@ -31,13 +31,12 @@
 #include <sys/time.h>
 #include <sys/types.h>
 
-#include "pcscdefines.h"
+#include "gempc_ifdhandler.h"
 #include "GemCore.h"
 #include "gbpserial.h"
 #include "Config.h"
 #include "GCdebug.h"
 #include "GCCmds.h"
-#include "ifdhandler.h"
 #include "GCUtils.h"
 
 /*
@@ -364,7 +363,7 @@ RESPONSECODE ReadGBP(DWORD lun, PDWORD length, PUCHAR buffer)
  *				OpenGBP: open the port
  *
  *****************************************************************************/
-RESPONSECODE OpenGBP(DWORD lun, LPSTR dev_name)
+RESPONSECODE OpenGBP(DWORD lun, LPTSTR dev_name)
 {
 	struct termios current_termios;
 	int ospeed, i;
