@@ -18,7 +18,7 @@
 */
 
 /*
- * $Id: main.c,v 1.16 2004/01/20 13:41:17 rousseau Exp $
+ * $Id: main.c,v 1.18 2004/07/03 21:42:45 rousseau Exp $
  */
 
 #include <stdio.h>
@@ -26,17 +26,18 @@
 #include <winscard.h>
 #include <string.h>
 
-#include "ifdhandler.h"
+#include "gempc_ifdhandler.h"
 #include "Config.h"
 #include "GCdebug.h"
 
-// CHANNELID:
-//  0x000001 - /dev/pcsc/1
-//  0x000002 - /dev/pcsc/2
-//  0x000003 - /dev/pcsc/3
+/* CHANNELID:
+ /  0x000001 - /dev/pcsc/1
+ /  0x000002 - /dev/pcsc/2
+ /  0x000003 - /dev/pcsc/3
+ /  0x000004 - /dev/pcsc/4 */
 
-// 1 -> GCR400
-// 2 -> GemPC410
+/* 1 -> GCR400
+ / 2 -> GemPC410 */
 #define SERIAL_PORT 2
 #define SERIAL_NAME "/dev/pcsc/2"
 
