@@ -1,6 +1,6 @@
 /*
  * libusb_wrap.c
- * $Id: libusb_wrap.c,v 1.1.1.6 2004/02/27 22:48:08 rousseau Exp $
+ * $Id: libusb_wrap.c,v 1.1.1.7 2004/07/24 21:57:24 rousseau Exp $
  * USB access routines using the libusb library
  *
  * Created by Ludovic Rousseau on Sep 27 2002
@@ -13,7 +13,7 @@
 #include <errno.h>
 #include <usb.h>
 
-#include "pcscdefines.h"
+#include "gempc_ifdhandler.h"
 #include "Config.h"
 #include "GCdebug.h"
 #include "GCUtils.h"
@@ -73,7 +73,7 @@ static _usbDevice usbDevice[PCSCLITE_MAX_READERS] = {
  *					OpenUSB
  *
  ****************************************************************************/
-status_t OpenUSB(DWORD lun, LPSTR device)
+status_t OpenUSB(DWORD lun, LPTSTR device)
 {
 	static struct usb_bus *busses = NULL;
 	int id, id_number;
