@@ -1,6 +1,6 @@
 /*
  *  GCCmds.c
- *  $Id: GCCmds.c,v 1.31 2004/02/27 22:15:09 rousseau Exp $
+ *  $Id: GCCmds.c,v 1.34 2004/08/08 15:10:19 rousseau Exp $
  *  ifd-GemPC
  *
  *  Created by Jean-Luc Giraud on Sat Oct 20 2001.
@@ -15,8 +15,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "pcscdefines.h"
-#include "ifdhandler.h"
+#include "gempc_ifdhandler.h"
 
 #include "Config.h"
 #include "GemCore.h"
@@ -37,73 +36,73 @@
 #error "GEMPC not defined: set it to 410 or 430"
 #endif
 
-// p. 18 Set Mode
+/* p. 18 Set Mode */
 #define IFD_CMD_MODE_SET1       0x01
 #define IFD_CMD_MODE_SET2       0x00
 
-// p. 17 Configure SIO line
+/* p. 17 Configure SIO line */
 #define IFD_CMD_SIO_SET         0x0A
 
-// p. 21 Restart, p. 22 Restart and Run Specified Application
+/* p. 21 Restart, p. 22 Restart and Run Specified Application */
 #define IFD_CMD_RESTART         0x0C
 
-// p. 24 Set Reader in Halt Mode
+/* p. 24 Set Reader in Halt Mode */
 #define IDF_CMD_HALT            0x0E
 
-// p. 26 Power Down
+/* p. 26 Power Down */
 #define IFD_CMD_ICC_POWER_DOWN  0x11
 
-// p. 34 Power Up - Asynchronous Cards, p. 36 Change Card Communication
-// Parameters - Asynchronous Cards, p. 45 Power UP - EMV Compliant,
-// p. 51 Change Transparent Mode Parameters, p. 53 Power Up - Transparent
-// Mode,
-// p. 57 Power Up - Synchronous Cards
+/* p. 34 Power Up - Asynchronous Cards, p. 36 Change Card Communication
+ * Parameters - Asynchronous Cards, p. 45 Power UP - EMV Compliant,
+ * p. 51 Change Transparent Mode Parameters, p. 53 Power Up - Transparent
+ * Mode,
+ * p. 57 Power Up - Synchronous Cards */
 #define IFD_CMD_ICC_POWER_UP    0x12
 
-// options for IFD_CMD_ICC_POWER_UP command, p. 34
-// Class A: Vcc for card is 5V
+/* options for IFD_CMD_ICC_POWER_UP command, p. 34
+ * Class A: Vcc for card is 5V */
 #define IFD_CMD_ICC_POWER_UP_OPT_5V 0x01
-// Class B: Vcc for card is 3V
+/* Class B: Vcc for card is 3V */
 #define IFD_CMD_ICC_POWER_UP_OPT_3V 0x02
-// Class AB: Vcc for card is 5V or 3V
+/* Class AB: Vcc for card is 5V or 3V */
 #define IFD_CMD_ICC_POWER_UP_OPT_5V_3V (IFD_CMD_ICC_POWER_UP_OPT_5V|IFD_CMD_ICC_POWER_UP_OPT_3V)
-// Reset and no PPS management. The reader stays at 9600 baud if the card is
-// in negotiable mode
+/* Reset and no PPS management. The reader stays at 9600 baud if the card is
+ * in negotiable mode */
 #define IFD_CMD_ICC_POWER_UP_OPT_NO_PPS_MNGT 0x10
 
-// Reset and no PPS management. Reader switches to maximum speed and T=1 if
-// card in negotiable mode
+/* Reset and no PPS management. Reader switches to maximum speed and T=1 if
+ * card in negotiable mode */
 #define IFD_CMD_ICC_POWER_UP_OPT_AUTO_PPS_MNGT 0x20
 
-// p. 38 ISO Output - Asynchronous Card,
-// p. 58 Read Data From Synchronous Card (ISO Out)
+/* p. 38 ISO Output - Asynchronous Card,
+ * p. 58 Read Data From Synchronous Card (ISO Out) */
 #define IFD_CMD_ICC_ISO_OUT     0x13
 
-// p. 39 ISO Input - Asynchronous Card,
-// p. 59 Send Data to Synchronous Card (ISO In)
+/* p. 39 ISO Input - Asynchronous Card,
+ * p. 59 Send Data to Synchronous Card (ISO In) */
 #define IFD_CMD_ICC_ISO_IN      0x14
 
-// p. 40 Exchange APDU - Asynchronous Card,
-// p. 46 Exchange APDU - EMV Compliant,
-// p. 54 Exchange Block - Transparent Mode,
-// p. 60 Exchange with Synchronous Card (ADPU)
+/* p. 40 Exchange APDU - Asynchronous Card,
+ * p. 46 Exchange APDU - EMV Compliant,
+ * p. 54 Exchange Block - Transparent Mode,
+ * p. 60 Exchange with Synchronous Card (ADPU) */
 #define IFD_CMD_ICC_APDU        0x15
 
 #define IFD_CMD_ICC_SYNCHRONE   0x16
 
 #define IFD_CMD_ICC_DISPATCHER  "\x17\x01"
 
-// p. 27 Define Main Card Type and Card Presence Detection
+/* p. 27 Define Main Card Type and Card Presence Detection */
 #define IFD_CMD_ICC_DEFINE_TYPE 0x17
 
-// p. 43 Card Status - Asynchronous Card,
-// p. 49 Card Status - EMV Compliant,
-// p. 55 Card Status - Transparent Mode,
-// p. 61 Card Status - Synchronous Card
+/* p. 43 Card Status - Asynchronous Card,
+ * p. 49 Card Status - EMV Compliant,
+ * p. 55 Card Status - Transparent Mode,
+ * p. 61 Card Status - Synchronous Card */
 #define IFD_CMD_ICC_STATUS      0x17
 
-// p. 31 Directory,
-// p. 32 Set Operating Mode
+/* p. 31 Directory,
+ * p. 32 Set Operating Mode */
 #define IFD_CMD_DIR1            0x17
 #define IFD_CMD_DIR2            0x00
 #define IFD_EMV_MODE			0x45
@@ -111,85 +110,85 @@
 
 #define IFD_CMD_MOD_POWER_DOWN  0x19
 
-// p. 34 Power Up - Asynchronous Cards,
-// p. 36 Change Card Communication Parameters - Asynchronous Cards,
-// p. 45 Power UP - EMV Compliant,
-// p. 51 Change Transparent Mode Parameters,
-// p. 53 Power Up - Transparent Mode,
-// p. 57 Power Up - Synchronous Cards
+/* p. 34 Power Up - Asynchronous Cards,
+ * p. 36 Change Card Communication Parameters - Asynchronous Cards,
+ * p. 45 Power UP - EMV Compliant,
+ * p. 51 Change Transparent Mode Parameters,
+ * p. 53 Power Up - Transparent Mode,
+ * p. 57 Power Up - Synchronous Cards */
 #define IFD_CMD_MOD_POWER_UP    0x1A
 
-// p. 38 ISO Output - Asynchronous Card,
-// p. 58 Read Data From Synchronous Card (ISO Out)
+/* p. 38 ISO Output - Asynchronous Card,
+ * p. 58 Read Data From Synchronous Card (ISO Out) */
 #define IFD_CMD_MOD_ISO_OUT     0x1B
 
-// p. 39 ISO Input - Asynchronous Card,
-// p. 59 Send Data to Synchronous Card (ISO In)
+/* p. 39 ISO Input - Asynchronous Card,
+ * p. 59 Send Data to Synchronous Card (ISO In) */
 #define IFD_CMD_MOD_ISO_IN      0x1C
 
-// p. 40 Exchange APDU - Asynchronous Card,
-// p. 46 Exchange APDU - EMV Compliant,
-// p. 54 Exchange Block - Transparent Mode,
-// p. 60 Exchange with Synchronous Card (ADPU)
+/* p. 40 Exchange APDU - Asynchronous Card,
+ * p. 46 Exchange APDU - EMV Compliant,
+ * p. 54 Exchange Block - Transparent Mode,
+ * p. 60 Exchange with Synchronous Card (ADPU) */
 #define IFD_CMD_MOD_APDU        0x1D
 
 #define IFD_CMD_MOD_SYNCHRONE   0x1E
 
-// p. Define Type and Select Auxiliary Card
+/* p. Define Type and Select Auxiliary Card */
 #define IFD_CMD_MOD_DEFINE_TYPE 0x1F
 
 #define IFD_CMD_MOD_DISPATCHER  "\x1F\x01"
 
-// p. 43 Card Status - Asynchronous Card,
-// p. 49 Card Status - EMV Compliant,
-// p. 55 Card Status - Transparent Mode,
-// p. 61 Card Status - Synchronous Card
+/* p. 43 Card Status - Asynchronous Card,
+ * p. 49 Card Status - EMV Compliant,
+ * p. 55 Card Status - Transparent Mode,
+ * p. 61 Card Status - Synchronous Card */
 #define IFD_CMD_MOD_STATUS      0x1F
 
-// p. 20 Read Firmware Version,
-// p. 63 Read Memory
+/* p. 20 Read Firmware Version,
+ * p. 63 Read Memory */
 #define IFD_CMD_MEM_RD          0x22
 
-// p. 19 Set Delay,
-// p. 64 Write Memory
+/* p. 19 Set Delay,
+ * p. 64 Write Memory */
 #define IFD_CMD_MEM_WR          0x23
 
-// p. 69 Read CPU Port
+/* p. 69 Read CPU Port */
 #define IFD_CMD_CPU_RD          0x24
 
-// p. 70 Write CPU Port
+/* p. 70 Write CPU Port */
 #define IFD_CMD_CPU_WR          0x25
 
-// p. 66 Erase Flash Memory
+/* p. 66 Erase Flash Memory */
 #define IFD_CMD_MEM_ERASE       0x26
 
-// p. 68 Select External Memory Page
+/* p. 68 Select External Memory Page */
 #define IFD_CMD_MEM_SELECT      0x27
 
 #define IFD_CMD_LCD_OFF         0x29
 
-// p. 72 Init the LCD
+/* p. 72 Init the LCD */
 #define IFD_CMD_LCD_ON          0x2A
 
-// p. 73 Display Character String
+/* p. 73 Display Character String */
 #define IFD_CMD_LCD_STRING      0x2B
 
-// p. 74 Display Character
+/* p. 74 Display Character */
 #define IFD_CMD_LCD_CHAR        0x2C
 
-// p. 75 Send LCD Command
+/* p. 75 Send LCD Command */
 #define IFD_CMD_LCD_CMD         0x2D
 
-// p. 77 Set Key Press Timeout
+/* p. 77 Set Key Press Timeout */
 #define IFD_CMD_KEY_TIMEOUT     0x32
 
-// p. 78 Sound Buzzer
+/* p. 78 Sound Buzzer */
 #define IFD_CMD_SOUND_BUZZER    0x33
 
-// p. 80 Read Date and Time
+/* p. 80 Read Date and Time */
 #define IFD_CMD_RTC_RD          0x3A
 
-// p. 81 Update Date and Time
+/* p. 81 Update Date and Time */
 #define IFD_CMD_RTC_WR          0x3B
 
 #define IFD_CMD_IO_RD           0x42
@@ -203,7 +202,7 @@
 #define IFD_ADD_VERSION_LOW 0xE0
 
 
-ifd_t GCCmdPowerDown(DWORD lun)
+ifd_t GCCmdPowerDown(const DWORD lun)
 {
 	UCHAR cmd[] = { IFD_CMD_ICC_POWER_DOWN };
 	ifd_t rv;
@@ -211,7 +210,7 @@ ifd_t GCCmdPowerDown(DWORD lun)
 
 	DEBUG_INFO("");
 
-	// PowerDown the card
+	/* PowerDown the card */
 	rv = GCMakeCommand(lun, sizeof(cmd), cmd, NULL, NULL, &gc_rv);
 	GCGemCoreError(gc_rv, __FILE__, __LINE__, __FUNCTION__);
 
@@ -219,14 +218,14 @@ ifd_t GCCmdPowerDown(DWORD lun)
 		return rv;
 
 	if (gc_rv != GCORE_OK)
-		// There is a problem in power down
+		/* There is a problem in power down */
 		return IFD_ERROR_POWER_ACTION;
 
 	return IFD_SUCCESS;
 } /* GCCmdPowerDown */
 
 
-ifd_t GCCmdPowerUp(DWORD lun, PDWORD nlength, UCHAR buffer[])
+ifd_t GCCmdPowerUp(const DWORD lun, PDWORD nlength, UCHAR buffer[])
 {
 #ifdef AUTOMATIC_PPS
 	UCHAR cmd_auto_pps[] = { IFD_CMD_ICC_POWER_UP,
@@ -245,7 +244,7 @@ ifd_t GCCmdPowerUp(DWORD lun, PDWORD nlength, UCHAR buffer[])
 	DEBUG_INFO("");
 
 #ifdef AUTOMATIC_PPS
-	// PowerUp the card with automatic PPS negociation
+	/* PowerUp the card with automatic PPS negociation */
 	rv = GCMakeCommand(lun, sizeof(cmd_auto_pps), cmd_auto_pps, nlength,
 		buffer, &gc_rv);
 	GCGemCoreError(gc_rv, __FILE__, __LINE__, __FUNCTION__);
@@ -253,7 +252,7 @@ ifd_t GCCmdPowerUp(DWORD lun, PDWORD nlength, UCHAR buffer[])
 	if (rv != IFD_SUCCESS)
 		return rv;
 
-	// There is a problem in power up: try with NO PPS
+	/* There is a problem in power up: try with NO PPS */
 	if ((gc_rv != GCORE_OK) && (gc_rv != GCORE_WRONG_TCK))
 #endif
 	{
@@ -264,36 +263,36 @@ ifd_t GCCmdPowerUp(DWORD lun, PDWORD nlength, UCHAR buffer[])
 		if (rv != IFD_SUCCESS)
 			return rv;
 
-		// There is a problem in power up: try to use EMV mode
+		/* There is a problem in power up: try to use EMV mode */
 		if ((gc_rv != GCORE_OK) && (gc_rv != GCORE_WRONG_TCK))
 		{
-			// power up: will return a 0xA0 error or EMV ok
+			/* power up: will return a 0xA0 error or EMV ok */
 			rv = GCMakeCommand(lun, sizeof(cmd_emv), cmd_emv, nlength,
 				buffer, &gc_rv);
 			GCGemCoreError(gc_rv, __FILE__, __LINE__, __FUNCTION__);
 
-			// If the card is NOT EMV we continue
+			/* If the card is NOT EMV we continue */
 			if (gc_rv != GCORE_OK)
 			{
-				// set mode to ISO
+				/* set mode to ISO */
 				rv = GCMakeCommand(lun, sizeof(cmd_set_operating_mode),
 					cmd_set_operating_mode, nlength, buffer, &gc_rv);
 				GCGemCoreError(gc_rv, __FILE__, __LINE__, __FUNCTION__);
 
-				// new power up
+				/* new power up */
 				rv = GCMakeCommand(lun, sizeof(cmd_emv), cmd_emv, nlength,
 					buffer, &gc_rv);
 				GCGemCoreError(gc_rv, __FILE__, __LINE__, __FUNCTION__);
 			}
 			else
-				// the card is EMV
+				/* the card is EMV */
 				IFDSetEmv(lun);
 
 			if (rv != IFD_SUCCESS)
 				return rv;
 		}
 
-		// There is a problem in power up
+		/* There is a problem in power up */
 		if ((gc_rv != GCORE_OK) && (gc_rv != GCORE_WRONG_TCK))
 			return IFD_ERROR_POWER_ACTION;
 	}
@@ -302,7 +301,7 @@ ifd_t GCCmdPowerUp(DWORD lun, PDWORD nlength, UCHAR buffer[])
 } /* GCCmdPowerUp */
 
 
-ifd_t GCCmdGetOSVersion(DWORD lun, PDWORD length, UCHAR buffer[])
+ifd_t GCCmdGetOSVersion(const DWORD lun, PDWORD length, UCHAR buffer[])
 {
  /*
 	 * GCR 400      (OROS): 'OROS-R2.24RM    ' (without ')
@@ -347,7 +346,7 @@ ifd_t GCCmdGetOSVersion(DWORD lun, PDWORD length, UCHAR buffer[])
 } /* GCCmdGetOSVersion */
 
 
-ifd_t GCCmdConfigureSIOLine(DWORD lun, int baudrate)
+ifd_t GCCmdConfigureSIOLine(const DWORD lun, const int baudrate)
 {
 	UCHAR cmd[] = { IFD_CMD_SIO_SET, 0x00 };
 	ifd_t rv;
@@ -380,7 +379,7 @@ ifd_t GCCmdConfigureSIOLine(DWORD lun, int baudrate)
 } /* GCCmdConfigureSIOLine */
 
 
-ifd_t GCCmdCardStatus(DWORD lun, UCHAR response[], PDWORD length)
+ifd_t GCCmdCardStatus(const DWORD lun, UCHAR response[], PDWORD length)
 {
 	UCHAR cmd[] = { IFD_CMD_ICC_STATUS };
 	ifd_t rv;
@@ -398,7 +397,7 @@ ifd_t GCCmdCardStatus(DWORD lun, UCHAR response[], PDWORD length)
 } /* GCCmdCardStatus */
 
 
-ifd_t GCCmdSetMode(DWORD lun, int mode)
+ifd_t GCCmdSetMode(const DWORD lun, const int mode)
 {
 	UCHAR cmd[] = { IFD_CMD_MODE_SET1, IFD_CMD_MODE_SET2, mode};
 	ifd_t rv;
@@ -406,7 +405,7 @@ ifd_t GCCmdSetMode(DWORD lun, int mode)
 
 	DEBUG_INFO("");
 
-	// success by default
+	/* success by default */
 	rv = IFD_SUCCESS;
 
 	switch (mode)
@@ -415,7 +414,7 @@ ifd_t GCCmdSetMode(DWORD lun, int mode)
 			rv = GCMakeCommand(lun, sizeof(cmd), cmd, NULL, NULL, &gc_rv);
 			GCGemCoreError(gc_rv, __FILE__, __LINE__, __FUNCTION__);
 
-			// The command in unknown if ROS is disabled
+			/* The command in unknown if ROS is disabled */
 			if ((gc_rv != GCORE_UNKNOWN_CMD) && (gc_rv != GCORE_OK))
 				rv = IFD_COMMUNICATION_ERROR;
 			break;
@@ -429,7 +428,7 @@ ifd_t GCCmdSetMode(DWORD lun, int mode)
 } /* GCCmdSetMode */
 
 
-ifd_t GCMakeCommand(DWORD lun, DWORD nLengthIn,
+ifd_t GCMakeCommand(const DWORD lun, const DWORD nLengthIn,
 	const UCHAR pcBufferCmd[], PDWORD pnLengthOut, UCHAR pcBufferOut[],
 	gcore_t *response)
 {
@@ -440,33 +439,33 @@ ifd_t GCMakeCommand(DWORD lun, DWORD nLengthIn,
 	lengthout = sizeof(buffer);
 	rv = GCSendCommand(lun, nLengthIn, pcBufferCmd, &lengthout, buffer);
 
-	// transport level error
+	/* transport level error */
 	if (rv != STATUS_SUCCESS)
 		return IFD_COMMUNICATION_ERROR;
 
-	// GemCore level error
+	/* GemCore level error */
 	*response = buffer[GC_STATUS_OFFSET];
 
-	// shift command anwser (remove GemCore status byte)
+	/* shift command anwser (remove GemCore status byte) */
 	if (pcBufferOut)
 		memcpy(pcBufferOut, buffer+1, lengthout-1);
 
-	// status byte removed
+	/* status byte removed */
 	if (pnLengthOut)
 		*pnLengthOut = lengthout-1;
 
 	return IFD_SUCCESS;
 } /* GCMakeCommand */
 
-UCHAR GCGemCoreError(UCHAR rv, char *file, int line, char *function)
+UCHAR GCGemCoreError(const UCHAR rv, const char *file, const int line, const char *function)
 {
 	char *text = NULL;
 	char do_output = TRUE;
 
-	// what is the GemCore status?
+	/* what is the GemCore status? */
 	switch (rv)
 	{
-		// normal error code
+		/* normal error code */
 		case GCORE_OK:
 			do_output = FALSE;
 			break;
@@ -539,7 +538,7 @@ UCHAR GCGemCoreError(UCHAR rv, char *file, int line, char *function)
 			text = "The card just sent an invalid Procedure Byte";
 			break;
 
-		// normal error code
+		/* normal error code */
 		case GCORE_CARD_EXC_INT:
 #ifdef DEBUG_LEVEL_INFO
 			text = "Card interrupted the exchange after SW1";
@@ -548,7 +547,7 @@ UCHAR GCGemCoreError(UCHAR rv, char *file, int line, char *function)
 #endif
 			break;
 
-		// normal error code
+		/* normal error code */
 		case GCORE_NOT_9000:
 #if 0
 			DEBUG_INFO("\"Error\" returned by the card (SW is not 9000)");
