@@ -1,5 +1,5 @@
 /*
- *  $Id: GCUtils.c,v 1.19 2004/02/27 22:15:09 rousseau Exp $
+ *  $Id: GCUtils.c,v 1.21 2004/07/03 21:42:48 rousseau Exp $
  *  GCUtils.c
  *  ifd-GemPC
  *
@@ -14,8 +14,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "pcscdefines.h"
-#include "ifdhandler.h"
+#include "gempc_ifdhandler.h"
 #include "Config.h"
 #include "GCUtils.h"
 #include "GCTransport.h"
@@ -23,24 +22,24 @@
 #include "GCdebug.h"
 #include "GCCmds.h"
 
-// p. 38 ISO Output - Asynchronous Card,
-// p. 58 Read Data From Synchronous Card (ISO Out)
+/* p. 38 ISO Output - Asynchronous Card,
+ * p. 58 Read Data From Synchronous Card (ISO Out) */
 #define IFD_CMD_ICC_ISO_OUT     0x13
 
-// p. 39 ISO Input - Asynchronous Card,
-// p. 59 Send Data to Synchronous Card (ISO In)
+/* p. 39 ISO Input - Asynchronous Card,
+ * p. 59 Send Data to Synchronous Card (ISO In) */
 #define IFD_CMD_ICC_ISO_IN      0x14
 
-// p. 40 Exchange APDU - Asynchronous Card,
-// p. 46 Exchange APDU - EMV Compliant,
-// p. 54 Exchange Block - Transparent Mode,
-// p. 60 Exchange with Synchronous Card (ADPU)
+/* p. 40 Exchange APDU - Asynchronous Card,
+ * p. 46 Exchange APDU - EMV Compliant,
+ * p. 54 Exchange Block - Transparent Mode,
+ * p. 60 Exchange with Synchronous Card (ADPU) */
 #define IFD_CMD_ICC_APDU        0x15
 
 const UCHAR pcLongDataADPU[] = { 0xFF, 0xFF, 0xFF, 0xFF, 0xFF };
 
-// Check if the Lun is not to large for the pgSlots table
-// returns TRUE in case of error
+/* Check if the Lun is not to large for the pgSlots table
+ * returns TRUE in case of error */
 int iLunCheck(DWORD Lun)
 {
 	if ((LunToReaderIndex(Lun) >= PCSCLITE_MAX_READERS) ||
@@ -57,16 +56,16 @@ ifd_t gemcore_ISO_OUTPUT_processing(DWORD Lun, PUCHAR TxBuffer,
 	UCHAR pcbuffer[RESP_BUF_SIZE];
 	DWORD nlength,
 	 ntemp_length;
-	ifd_t return_value = IFD_SUCCESS;	// Assume it will work
+	ifd_t return_value = IFD_SUCCESS;	/* Assume it will work */
 
 	DEBUG_INFO("");
 
-	// Buffer only holds an APDU (no Data),
-	// output command
+	/* Buffer only holds an APDU (no Data),
+	 * output command */
 	pccmd_buffer[GC_OFFSET_CMD] = IFD_CMD_ICC_ISO_OUT;
 	memcpy(pccmd_buffer + GC_OFFSET_APDU, TxBuffer, TxLength);
 
-	// Send the command
+	/* Send the command */
 	nlength = sizeof(pcbuffer);
 	if (GCSendCommand(Lun, TxLength + GC_SIZE_CMD, pccmd_buffer,
 			&nlength, pcbuffer) != STATUS_SUCCESS)
@@ -76,26 +75,26 @@ ifd_t gemcore_ISO_OUTPUT_processing(DWORD Lun, PUCHAR TxBuffer,
 		goto clean_up_and_return;
 	}
 
-	// Copy RxLength to memorize the RxBuffer size
+	/* Copy RxLength to memorize the RxBuffer size */
 	ntemp_length = *RxLength;
 	return_value = gemcore_status_processing(nlength, RxLength, pcbuffer,
 		RxBuffer);
 
-	// Check if command was successful
+	/* Check if command was successful */
 	if (return_value != IFD_SUCCESS)
 		goto clean_up_and_return;
 
-	// Check if there is more data to fetch
-	// First check for 0 length
+	/* Check if there is more data to fetch
+	 * First check for 0 length */
 	if (TxBuffer[ISO_OFFSET_LENGTH] == 0)
 	{
-		// APDU Lenght byte is 0, check if card sent Data (256 Data)
+		/* APDU Lenght byte is 0, check if card sent Data (256 Data) */
 		if (nlength <= (ISO_SIZE_SW + GC_READER_TRANSMIT_RESP_LENGTH))
-			// Length was 0 and card returned no data: Case 1 command
+			/* Length was 0 and card returned no data: Case 1 command */
 			goto clean_up_and_return;
 
-		// Data are left
-		// set nlength to remaining space avaliable in RxBuffer
+		/* Data are left
+		 * set nlength to remaining space avaliable in RxBuffer */
 		nlength = ntemp_length - *RxLength;
 		if (nlength <= 0)
 		{
@@ -103,7 +102,7 @@ ifd_t gemcore_ISO_OUTPUT_processing(DWORD Lun, PUCHAR TxBuffer,
 			goto clean_up_and_return;
 		}
 
-		// Retrieve remaining data and paste it after the first half
+		/* Retrieve remaining data and paste it after the first half */
 		return_value = gemcore_long_data_OUTPUT_processing(Lun,
 			IFD_CMD_ICC_ISO_OUT, nlength, RxLength,
 			RxBuffer + *RxLength);
@@ -112,18 +111,18 @@ ifd_t gemcore_ISO_OUTPUT_processing(DWORD Lun, PUCHAR TxBuffer,
 		if ((TxBuffer[ISO_OFFSET_LENGTH] > GC_ISO_OUTPUT_MAX_DATA_LENGTH) &&
 			(nlength-ISO_SIZE_SW >= GC_ISO_OUTPUT_MAX_DATA_LENGTH))
 		{
-			// Data are left
-			// set nlength to remaining space avaliable in pcbuffer
+			/* Data are left
+			 * set nlength to remaining space avaliable in pcbuffer */
 			nlength = ntemp_length - *RxLength;
 
-			// Retrieve remaining data and paste it after the first half
+			/* Retrieve remaining data and paste it after the first half */
 			return_value = gemcore_long_data_OUTPUT_processing(Lun,
 				IFD_CMD_ICC_ISO_OUT, nlength, RxLength,
 				RxBuffer + *RxLength);
 		}
 
 clean_up_and_return:
-	// Buffers clean-up
+	/* Buffers clean-up */
 	bzero(pccmd_buffer, sizeof(pccmd_buffer));
 	bzero(pcbuffer, sizeof(pcbuffer));
 
@@ -139,7 +138,7 @@ ifd_t gemcore_ISO_INPUT_processing(DWORD Lun, PUCHAR TxBuffer,
 	UCHAR pccmd_buffer[CMD_BUF_SIZE];
 	UCHAR pcbuffer[RESP_BUF_SIZE];
 	DWORD nlength;
-	ifd_t return_value = IFD_SUCCESS;	// Assume it will work
+	ifd_t return_value = IFD_SUCCESS;	/* Assume it will work */
 
 	DEBUG_INFO("");
 
@@ -153,7 +152,7 @@ ifd_t gemcore_ISO_INPUT_processing(DWORD Lun, PUCHAR TxBuffer,
 
 	if (!nlength)
 	{
-		// Data field present but Lc=0, forbidden
+		/* Data field present but Lc=0, forbidden */
 		return_value = IFD_COMMUNICATION_ERROR;
 		goto clean_up_and_return;
 	}
@@ -161,13 +160,12 @@ ifd_t gemcore_ISO_INPUT_processing(DWORD Lun, PUCHAR TxBuffer,
 
 	if (TxLength < (nlength + ISO_CMD_SIZE + ISO_LENGTH_SIZE))
 	{
-		// Not enough Data in TxBuffer
+		/* Not enough Data in TxBuffer */
 		return_value = IFD_COMMUNICATION_ERROR;
 		goto clean_up_and_return;
 	}
 
-	// If length exceeds maximum for one exchange, send the last part
-	// first
+	/* If length exceeds maximum for one exchange, send the last part first */
 	if (nlength > GC_ISO_INPUT_MAX_DATA_LENGTH)
 	{
 		return_value = gemcore_long_data_INPUT_processing(Lun,
@@ -179,7 +177,7 @@ ifd_t gemcore_ISO_INPUT_processing(DWORD Lun, PUCHAR TxBuffer,
 		if (return_value != IFD_SUCCESS)
 			goto clean_up_and_return;
 
-		// Length to send is now smaller
+		/* Length to send is now smaller */
 		TxLength -= nlength - GC_ISO_INPUT_MAX_DATA_LENGTH;
 	}
 
@@ -199,7 +197,7 @@ ifd_t gemcore_ISO_INPUT_processing(DWORD Lun, PUCHAR TxBuffer,
 		RxBuffer);
 
 clean_up_and_return:
-	// Buffers clean-up
+	/* Buffers clean-up */
 	bzero(pccmd_buffer, sizeof(pccmd_buffer));
 	bzero(pcbuffer, sizeof(pcbuffer));
 
@@ -215,12 +213,11 @@ ifd_t gemcore_ISO_EXCHANGE_processing(DWORD Lun, PUCHAR TxBuffer,
 	UCHAR pccmd_buffer[CMD_BUF_SIZE];
 	UCHAR pcbuffer[RESP_BUF_SIZE];
 	DWORD nlength;
-	ifd_t return_value = IFD_SUCCESS;	// Assume it will work
+	ifd_t return_value = IFD_SUCCESS;	/* Assume it will work */
 
 	DEBUG_INFO("");
 
-	// If length exceeds maximum for one exchange, send the last part
-	// first
+	/* If length exceeds maximum for one exchange, send the last part first */
 	if (TxLength > GC_ISO_EXC_CMD_MAX_APDU_LENGTH)
 	{
 		return_value = gemcore_long_data_INPUT_processing(Lun,
@@ -231,18 +228,18 @@ ifd_t gemcore_ISO_EXCHANGE_processing(DWORD Lun, PUCHAR TxBuffer,
 		if (return_value != IFD_SUCCESS)
 			goto clean_up_and_return;
 
-		// Length to send is now smaller
+		/* Length to send is now smaller */
 		TxLength = GC_ISO_EXC_CMD_MAX_APDU_LENGTH;
 	}
 	
-	// Build the commmand
+	/* Build the commmand */
 	pccmd_buffer[GC_OFFSET_CMD] = IFD_CMD_ICC_APDU;
 	memcpy(pccmd_buffer + GC_OFFSET_APDU, TxBuffer, TxLength);
 
-	// Add length of expected data
+	/* Add length of expected data */
 	pccmd_buffer[GC_OFFSET_APDU + TxLength] = *RxLength;
 
-	// Send the command
+	/* Send the command */
 	nlength = sizeof(pcbuffer);
 	if (GCSendCommand(Lun, TxLength + GC_SIZE_CMD, pccmd_buffer,
 			&nlength, pcbuffer) != STATUS_SUCCESS)
@@ -254,7 +251,7 @@ ifd_t gemcore_ISO_EXCHANGE_processing(DWORD Lun, PUCHAR TxBuffer,
 
 	if (nlength < GC_SIZE_STATUS)
 	{
-		// Length should at least be GC_SIZE_STATUS (reader status)
+		/* Length should at least be GC_SIZE_STATUS (reader status) */
 		return IFD_COMMUNICATION_ERROR;
 	}
 
@@ -263,30 +260,30 @@ ifd_t gemcore_ISO_EXCHANGE_processing(DWORD Lun, PUCHAR TxBuffer,
 
 		if (nlength != (GC_ISO_EXC_RESP_MAX_APDU_LENGTH + GC_SIZE_STATUS))
 		{
-			// Should have received a full block
+			/* Should have received a full block */
 			return_value = IFD_COMMUNICATION_ERROR;
 			goto clean_up_and_return;
 		}
 
-		// There are extra data to fetch on the reader
-		// store what was receive
+		/* There are extra data to fetch on the reader
+		 * store what was receive */
 		if (*RxLength <= (GC_ISO_EXC_RESP_MAX_APDU_LENGTH))
 		{
 			memcpy(RxBuffer, pcbuffer + GC_OFFSET_RESP_DATA, *RxLength);
-			// No space left in buffer, return directly
+			/* No space left in buffer, return directly */
 			goto clean_up_and_return;
 		}
 		
 		memcpy(RxBuffer, pcbuffer + GC_OFFSET_RESP_DATA,
 			GC_ISO_EXC_RESP_MAX_APDU_LENGTH);
 		
-		// set nlength to remaining space avaliable in RxBuffer
+		/* set nlength to remaining space avaliable in RxBuffer */
 		nlength = *RxLength - GC_ISO_EXC_RESP_MAX_APDU_LENGTH;
 
-		// set RxLength to what was already received
+		/* set RxLength to what was already received */
 		*RxLength = GC_ISO_EXC_RESP_MAX_APDU_LENGTH;
 
-		// Retrieve remaining data and paste it after the first half
+		/* Retrieve remaining data and paste it after the first half */
 		return_value =
 			gemcore_long_data_OUTPUT_processing(Lun,
 			IFD_CMD_ICC_APDU, nlength, RxLength,
@@ -297,7 +294,7 @@ ifd_t gemcore_ISO_EXCHANGE_processing(DWORD Lun, PUCHAR TxBuffer,
 			pcbuffer, RxBuffer);
 
 clean_up_and_return:
-	// Buffers clean-up
+	/* Buffers clean-up */
 	bzero(pccmd_buffer, sizeof(pccmd_buffer));
 	bzero(pcbuffer, sizeof(pcbuffer));
 
@@ -313,7 +310,7 @@ ifd_t gemcore_status_processing(DWORD nlength, PDWORD RxLength,
 	DEBUG_INFO("");
 
 	if (nlength < GC_SIZE_STATUS)
-		// Length should at least be GC_SIZE_STATUS (reader status)
+		/* Length should at least be GC_SIZE_STATUS (reader status) */
 		return IFD_COMMUNICATION_ERROR;
 
 	nlength -= GC_SIZE_STATUS;
@@ -322,9 +319,9 @@ ifd_t gemcore_status_processing(DWORD nlength, PDWORD RxLength,
 	{
 		case GCORE_OK:
 		case GCORE_NOT_9000:
-		case GCORE_CARD_EXC_INT:	// SW=6700
-			// if ( nlength < pcbuffer[OFFSET_LNG] )
-			// WHAT SHOULD WE DO
+		case GCORE_CARD_EXC_INT:	/* SW=6700 */
+			/* if ( nlength < pcbuffer[OFFSET_LNG] ) */
+			/* WHAT SHOULD WE DO */
 			*RxLength = (*RxLength < nlength) ? (*RxLength) : nlength;
 			memcpy(RxBuffer, pcbuffer + GC_OFFSET_RESP_DATA, *RxLength);
 			break;
@@ -339,7 +336,7 @@ ifd_t gemcore_status_processing(DWORD nlength, PDWORD RxLength,
 			return IFD_ICC_NOT_PRESENT;
 
 		default:
-			// There was a problem in sending the command
+			/* There was a problem in sending the command */
 			return IFD_COMMUNICATION_ERROR;
 	}
 	return IFD_SUCCESS;
@@ -356,27 +353,27 @@ ifd_t gemcore_long_data_INPUT_processing(DWORD Lun, UCHAR cCMD,
 
 	DEBUG_INFO("");
 
-	// command
+	/* command */
 	pccmd_buffer[GC_OFFSET_CMD] = cCMD;
 
-	// use specific APDU
+	/* use specific APDU */
 	memcpy(pccmd_buffer + GC_OFFSET_APDU, pcLongDataADPU,
 		sizeof(pcLongDataADPU));
 
-	// modify the length byte
+	/* modify the length byte */
 	pccmd_buffer[GC_OFFSET_LENGTH] = (UCHAR) ndatalength;
 
-	// Check the space left in pccmd_buffer
+	/* Check the space left in pccmd_buffer */
 	if (sizeof(pccmd_buffer) < (GC_OFFSET_TPDU_CMD_DATA + ndatalength))
 	{
 		return_value = IFD_COMMUNICATION_ERROR;
 		goto clean_up_and_return;
 	}
 
-	// Add the Data (last data bytes of the command
+	/* Add the Data (last data bytes of the command */
 	memcpy(pccmd_buffer + GC_OFFSET_TPDU_CMD_DATA, pcbuffer, ndatalength);
 
-	// Send the command
+	/* Send the command */
 	nlength = sizeof(pcresp_buffer);
 
 	if (GCSendCommand(Lun,
@@ -413,14 +410,14 @@ ifd_t gemcore_long_data_OUTPUT_processing(DWORD Lun, UCHAR cCMD,
 
 	DEBUG_INFO("");
 
-	// command
+	/* command */
 	pccmd_buffer[GC_OFFSET_CMD] = cCMD;
 
-	// use specific APDU
+	/* use specific APDU */
 	memcpy(pccmd_buffer + GC_OFFSET_APDU, pcLongDataADPU,
 		sizeof(pcLongDataADPU));
 
-	// Send the command
+	/* Send the command */
 	nlength = sizeof(pcresp_buffer);
 	if (GCSendCommand(Lun, sizeof(pcLongDataADPU) + GC_SIZE_CMD,
 			pccmd_buffer, &nlength, pcresp_buffer) != STATUS_SUCCESS)
