@@ -1,6 +1,6 @@
 /*
- * $Id: GCdebug.c,v 1.3 2001/11/06 23:04:17 rousseau Exp $
- * GCdebug.c: log (or not) messages using syslog
+ * $Id: GCdebug.c,v 1.6 2003/03/21 22:34:08 rousseau Exp $
+ * GCdebug.c: log (or not) messages
  * Copyright (C) 2001 Ludovic Rousseau <ludovic.rousseau@free.fr>
  * 
  * License: this code is under a double licence COPYING.BSD and COPYING.GPL
@@ -15,7 +15,6 @@
 
 #include <stdarg.h>
 #include <stdio.h>
-#include <syslog.h>
 #include <string.h>
 
 #define DEBUG_BUF_SIZE (256*3+30)
@@ -30,11 +29,7 @@ void debug_msg(char *fmt, ...)
 	vsnprintf(DebugBuffer, DEBUG_BUF_SIZE, fmt, argptr);
 	va_end(argptr);
 
-#ifdef DEBUG_STDERR
 	fprintf(stderr, "%s\n", DebugBuffer);
-#else
-	syslog(LOG_INFO, "%s", DebugBuffer);
-#endif
 } /* debug_msg */
 
 void debug_xxd(const char *msg, const unsigned char *buffer, const int len)
@@ -53,11 +48,7 @@ void debug_xxd(const char *msg, const unsigned char *buffer, const int len)
 		c += strlen(c);
 	}
 
-#ifdef DEBUG_STDERR
 	fprintf(stderr, "%s\n", DebugBuffer);
-#else
-	syslog(LOG_INFO, "%s", DebugBuffer);
-#endif
 } /* debug_xxd */
 
 #endif
