@@ -4,7 +4,7 @@
 / Authors :   David Corcoran <corcoran@linuxnet.com>
 /             Jean-Luc Giraud <jl.giraud@free.fr>
 /             Ludovic Rousseau <ludovic.rousseau@free.fr>
-/ Date   :   April 9, 2001, 2002, 2003
+/ Date   :   April 9, 2001, 2002, 2003, 2004
 / Purpose:   This provides reader specific low-level calls
 /            for the GemPC family of Gemplus. The function
 /            stubs were written by D. Corcoran, the GemCore
@@ -13,7 +13,7 @@
 /            See http://www.linuxnet.com for more information.
 / License:   See file COPYING.BSD
 /
-/ $Id: ifdhandler.c,v 1.22 2004/01/20 13:58:59 rousseau Exp $
+/ $Id: ifdhandler.c,v 1.25 2004/07/24 14:31:04 rousseau Exp $
 /
 ******************************************************************/
 
@@ -23,8 +23,7 @@
 #include <pthread.h>
 #endif
 
-#include "pcscdefines.h"
-#include "ifdhandler.h"
+#include "gempc_ifdhandler.h"
 #include "Config.h"
 #include "GemCore.h"
 #include "GCUtils.h"
@@ -43,22 +42,22 @@
 #error "GEMPC must be configured (set to 410 or 430)"
 #endif
 
-// Array of structures to hold the ATR and other state value of each slot
+/* Array of structures to hold the ATR and other state value of each slot */
 static GCoreDesc pgSlots[PCSCLITE_MAX_READERS];
 
 
-RESPONSECODE IFDHCreateChannelByName(DWORD Lun, LPSTR lpcDevice)
+RESPONSECODE IFDHCreateChannelByName(DWORD Lun, LPTSTR lpcDevice)
 {
 	DEBUG_INFO3("lun: %X, device: %s", Lun, lpcDevice);
 
 	if (iLunCheck(Lun))
 		return IFD_COMMUNICATION_ERROR;
 
-	// Reset ATR buffer
+	/* Reset ATR buffer */
 	pgSlots[LunToReaderIndex(Lun)].nATRLength = 0;
 	*pgSlots[LunToReaderIndex(Lun)].pcATRBuffer = '\0';
 
-	// Reset PowerFlags
+	/* Reset PowerFlags */
 	pgSlots[LunToReaderIndex(Lun)].bPowerFlags = POWERFLAGS_RAZ;
 
 	if (OpenPortByName(Lun, lpcDevice) != IFD_SUCCESS)
@@ -116,11 +115,11 @@ RESPONSECODE IFDHCreateChannel(DWORD Lun, DWORD Channel)
 	if (iLunCheck(Lun))
 		return IFD_COMMUNICATION_ERROR;
 
-	// Reset ATR buffer
+	/* Reset ATR buffer */
 	pgSlots[LunToReaderIndex(Lun)].nATRLength = 0;
 	*pgSlots[LunToReaderIndex(Lun)].pcATRBuffer = '\0';
 
-	// Reset PowerFlags
+	/* Reset PowerFlags */
 	pgSlots[LunToReaderIndex(Lun)].bPowerFlags =
 		POWERFLAGS_RAZ;
 
@@ -153,7 +152,7 @@ RESPONSECODE IFDHCloseChannel(DWORD Lun)
 		return IFD_COMMUNICATION_ERROR;
 
 	GCCmdPowerDown(Lun);
-	// No reader status check, if it failed, what can you do ? :)
+	/* No reader status check, if it failed, what can you do ? :) */
 
 	ClosePort(Lun);
 
@@ -190,9 +189,9 @@ RESPONSECODE IFDHGetCapabilities(DWORD Lun, DWORD Tag,
 	switch (Tag)
 	{
 		case TAG_IFD_ATR:
-			// If Length is not zero, powerICC has been performed.
-			// Otherwise, return NULL pointer
-			// Buffer size is stored in *Length
+			/* If Length is not zero, powerICC has been performed.
+			 * Otherwise, return NULL pointer
+			 * Buffer size is stored in *Length */
 			*Length = (*Length < pgSlots[LunToReaderIndex(Lun)].nATRLength) ?
 				*Length : pgSlots[LunToReaderIndex(Lun)].nATRLength;
 
@@ -236,7 +235,7 @@ RESPONSECODE IFDHSetCapabilities(DWORD Lun, DWORD Tag,
 	 * IFD_ERROR_VALUE_READ_ONLY
 	 */
 
-	// By default, say it worked
+	/* By default, say it worked */
 
 	DEBUG_PERIODIC3("lun: %X, tag: %X", Lun, Tag);
 
@@ -319,7 +318,7 @@ RESPONSECODE IFDHPowerICC(DWORD Lun, DWORD Action,
 
 	DEBUG_INFO2("lun: %X", Lun);
 
-	// By default, assume it won't work :)
+	/* By default, assume it won't work :) */
 	*AtrLength = 0;
 
 	if (iLunCheck(Lun))
@@ -336,11 +335,11 @@ RESPONSECODE IFDHPowerICC(DWORD Lun, DWORD Action,
 				goto end;
 			}
 
-			// Power up successful, set state variable to memorise it
+			/* Power up successful, set state variable to memorise it */
 			pgSlots[LunToReaderIndex(Lun)].bPowerFlags |= MASK_POWERFLAGS_PUP;
 			pgSlots[LunToReaderIndex(Lun)].bPowerFlags &= ~MASK_POWERFLAGS_PDWN;
 
-			// Reset is returned, even if TCK is wrong
+			/* Reset is returned, even if TCK is wrong */
 			pgSlots[LunToReaderIndex(Lun)].nATRLength = *AtrLength =
 				(nlength < MAX_ATR_SIZE) ? nlength : MAX_ATR_SIZE;
 			memcpy(Atr, pcbuffer, *AtrLength);
@@ -350,13 +349,13 @@ RESPONSECODE IFDHPowerICC(DWORD Lun, DWORD Action,
 			break;
 
 		case IFD_POWER_DOWN:
-			// Clear ATR buffer
+			/* Clear ATR buffer */
 			pgSlots[LunToReaderIndex(Lun)].nATRLength =
 				0;
 			*pgSlots[LunToReaderIndex(Lun)].pcATRBuffer = '\0';
-			// Memorise the request
+			/* Memorise the request */
 			pgSlots[LunToReaderIndex(Lun)].bPowerFlags |= MASK_POWERFLAGS_PDWN;
-			// send the command
+			/* send the command */
 			return_value = GCCmdPowerDown(Lun);
 			break;
 
@@ -409,7 +408,7 @@ RESPONSECODE IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 	 */
 
 	DWORD ntestlength;
-	RESPONSECODE return_value = IFD_SUCCESS;	// Assume it will work
+	RESPONSECODE return_value = IFD_SUCCESS;	/* Assume it will work */
 	DWORD protocol;
 
 	DEBUG_INFO2("lun: %X", Lun);
@@ -419,25 +418,25 @@ RESPONSECODE IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 
 	protocol = SendPci.Protocol;
 
-	// if the reader is in EMV mode use ISO_EXCHANGE instead of ISO_INPUT
-	// and ISO_OUTPUT. This is done with T=1 protocol
+	/* if the reader is in EMV mode use ISO_EXCHANGE instead of ISO_INPUT
+	 * and ISO_OUTPUT. This is done with T=1 protocol */
 	if (pgSlots[LunToReaderIndex(Lun)].bPowerFlags & MASK_POWERFLAGS_EMV)
 		protocol = T_1;
 
 	switch (protocol)
 	{
 		case T_0:
-			// Check if command is going to fit in buffer
+			/* Check if command is going to fit in buffer */
 			if (CMD_BUF_SIZE < (GC_SIZE_CMD + TxLength))
 			{
-				// Buffer too small, send an error
+				/* Buffer too small, send an error */
 				return_value = IFD_COMMUNICATION_ERROR;
 				goto clean_up_and_return;
 			}
 			
-			// Check if this is an incoming or outgoing command
-			// Size should be command + one byte of length for
-			// an outgoing TPDU (CLA, INS, P1, P2, P3)
+			/* Check if this is an incoming or outgoing command
+			 * Size should be command + one byte of length for
+			 * an outgoing TPDU (CLA, INS, P1, P2, P3) */
 			if (TxLength == (ISO_CMD_SIZE + ISO_LENGTH_SIZE))
 			{
 				return_value = gemcore_ISO_OUTPUT_processing(Lun,
@@ -447,14 +446,14 @@ RESPONSECODE IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 			}
 			else
 			{
-				// just (CLA, INS, P1, P2) for an APDU
+				/* just (CLA, INS, P1, P2) for an APDU */
 				if (TxLength == ISO_CMD_SIZE)
 				{
 					char cmd[ISO_CMD_SIZE + ISO_LENGTH_SIZE];
 
-					// copy CLA, INS, P1, P2
+					/* copy CLA, INS, P1, P2 */
 					memcpy(cmd, TxBuffer, ISO_CMD_SIZE);
-					// set P3 to 0
+					/* set P3 to 0 */
 					cmd[ISO_CMD_SIZE] = 0;
 
 					return_value = gemcore_ISO_INPUT_processing(Lun,
@@ -465,13 +464,13 @@ RESPONSECODE IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 				{
 					if (TxLength > (ISO_CMD_SIZE + ISO_LENGTH_SIZE))
 					{
-						// Check length to see if it is a full APDU or a TPDU
+						/* Check length to see if it is a full APDU or a TPDU */
 						ntestlength = TxBuffer[ISO_OFFSET_LENGTH] + ISO_CMD_SIZE
 							+ ISO_LENGTH_SIZE;
 
 						if (TxLength == (ntestlength + ISO_LENGTH_SIZE))
 						{
-							// TxBuffer holds a proper APDU
+							/* TxBuffer holds a proper APDU */
 							return_value = gemcore_ISO_EXCHANGE_processing(Lun,
 								TxBuffer, TxLength, RxBuffer, RxLength);
 							break;
@@ -479,19 +478,19 @@ RESPONSECODE IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 						else
 							if (TxLength > (ntestlength + ISO_LENGTH_SIZE))
 							{
-								// Data are too long
+								/* Data are too long */
 								return_value = IFD_COMMUNICATION_ERROR;
 
 								goto clean_up_and_return;
 							}
 
-						// Incoming TPDU
+						/* Incoming TPDU */
 						return_value = gemcore_ISO_INPUT_processing(Lun,
 							TxBuffer, TxLength, RxBuffer, RxLength);
 					}
 					else
 					{
-						// TxBuffer holds too little data to form an APDU+length
+						/* TxBuffer holds too little data to form an APDU+length */
 						return_value = IFD_COMMUNICATION_ERROR;
 
 						goto clean_up_and_return;
@@ -502,11 +501,11 @@ RESPONSECODE IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 			break;
 
 		case T_1:
-			// Check if command is going to fit in buffer
-			// cmd byte + TxLength + Le
+			/* Check if command is going to fit in buffer
+			 * cmd byte + TxLength + Le */
 			if (CMD_BUF_SIZE < (GC_SIZE_CMD + TxLength + ISO_LENGTH_SIZE))
 			{
-				// Buffer too small, send an error
+				/* Buffer too small, send an error */
 				return_value = IFD_COMMUNICATION_ERROR;
 				goto clean_up_and_return;
 			}
@@ -529,8 +528,8 @@ clean_up_and_return:
 } /* IFDHTransmitToICC */
 
 
-RESPONSECODE IFDHControl(DWORD Lun, PUCHAR TxBuffer,
-	DWORD TxLength, PUCHAR RxBuffer, PDWORD RxLength)
+RESPONSECODE IFDHControl(DWORD Lun, DWORD ControlCode, PUCHAR TxBuffer,
+	DWORD TxLength, PUCHAR RxBuffer, DWORD RxLength, PDWORD pdwBytesReturned)
 {
 	/*
 	 * This function performs a data exchange with the reader (not the
@@ -549,10 +548,10 @@ RESPONSECODE IFDHControl(DWORD Lun, PUCHAR TxBuffer,
 
 	DEBUG_INFO2("lun: %X", Lun);
 
-	if (iLunCheck(Lun))
-		return IFD_COMMUNICATION_ERROR;
+	/* this function is unsupported */
+	*pdwBytesReturned = 0;
 
-	return IFD_SUCCESS;
+	return IFD_COMMUNICATION_ERROR;
 } /* IFDHControl */
 
 
@@ -585,43 +584,43 @@ RESPONSECODE IFDHICCPresence(DWORD Lun)
 
 	if (GC_MASK_ICC_PRESENCE & pcbuffer[GC_OFFSET_STAT_BYTE])
 	{
-		// Card is present, but is it powered-up?
+		/* Card is present, but is it powered-up? */
 		if (GC_MASK_POWER & pcbuffer[GC_OFFSET_STAT_BYTE])
 		{
 			DEBUG_PERIODIC("Card present and powered");
-			// Powered, so the ressource manager did not miss a quick
-			// removal/re-insertion
+			/* Powered, so the ressource manager did not miss a quick
+			 * removal/re-insertion */
 			
 			return_value = IFD_ICC_PRESENT;
 			goto clean_up_and_return;
 		}
 		else
 		{
-			// Card present but not powered up
-			// Check if a power down has been requested
+			/* Card present but not powered up
+			 * Check if a power down has been requested */
 			if (pgSlots[LunToReaderIndex(Lun)].bPowerFlags & MASK_POWERFLAGS_PDWN)
 			{
 				DEBUG_PERIODIC("Card present not powered, power down requested");
-				// Powerdown requested, so situation is normal
+				/* Powerdown requested, so situation is normal */
 
 				return_value = IFD_ICC_PRESENT;
 				goto clean_up_and_return;
 			}
 
-			// Card inserted, not powered on but power down has not been
-			// requested
-			// Has the card been powered up already?
+			/* Card inserted, not powered on but power down has not been
+			 * requested
+			 * Has the card been powered up already? */
 			if (pgSlots[LunToReaderIndex(Lun)].bPowerFlags & MASK_POWERFLAGS_PUP)
 			{
 				DEBUG_PERIODIC("Card pull-out+re-insert detected CARD OUT SIMULATION");
-				// Power-up has been requested, but not power down and power is
-				// down.  This should happen only if the card has been pulled
-				// out and reinserted too quickly for the resource manager to
-				// realise. A card out event is therefore simulated. Clear ATR
-				// buffer
+				/* Power-up has been requested, but not power down and power is
+				 * down.  This should happen only if the card has been pulled
+				 * out and reinserted too quickly for the resource manager to
+				 * realise. A card out event is therefore simulated. Clear ATR
+				 * buffer */
 				pgSlots[LunToReaderIndex(Lun)].nATRLength = 0;
 				*pgSlots[LunToReaderIndex(Lun)].pcATRBuffer = '\0';
-				// reset power flags
+				/* reset power flags */
 				pgSlots[LunToReaderIndex(Lun)].bPowerFlags = POWERFLAGS_RAZ;
 
 				return_value = IFD_ICC_NOT_PRESENT;
@@ -629,12 +628,12 @@ RESPONSECODE IFDHICCPresence(DWORD Lun)
 			}
 
 			DEBUG_PERIODIC("Card present, just inserted");
-			// If control gets here, the card is in, not powered on, with
-			// no power down request and no previous power up request
-			// it is therefore a card insertion event
+			/* If control gets here, the card is in, not powered on, with
+			 * no power down request and no previous power up request
+			 * it is therefore a card insertion event */
 			pgSlots[LunToReaderIndex(Lun)].nATRLength = 0;
 			*pgSlots[LunToReaderIndex(Lun)].pcATRBuffer = '\0';
-			// reset power flags
+			/* reset power flags */
 			pgSlots[LunToReaderIndex(Lun)].bPowerFlags = POWERFLAGS_RAZ;
 			
 			return_value = IFD_ICC_PRESENT;
@@ -644,10 +643,10 @@ RESPONSECODE IFDHICCPresence(DWORD Lun)
 	else
 	{
 		DEBUG_PERIODIC("Card absent");
-		// Clear ATR buffer
+		/* Clear ATR buffer */
 		pgSlots[LunToReaderIndex(Lun)].nATRLength = 0;
 		*pgSlots[LunToReaderIndex(Lun)].pcATRBuffer = '\0';
-		// Card removed, clear the flags
+		/* Card removed, clear the flags */
 		pgSlots[LunToReaderIndex(Lun)].bPowerFlags =
 			POWERFLAGS_RAZ;
 
